@@ -97,12 +97,6 @@ def initialize_detector(detector_backend):
 		
 	elif detector_backend == 'mtcnn':
 		face_detector = MTCNN()
-	
-def loadBase64Img(uri):
-   encoded_data = uri.split(',')[1]
-   nparr = np.fromstring(base64.b64decode(encoded_data), np.uint8)
-   img = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
-   return img
 
 def initializeFolder():
 	
@@ -115,23 +109,12 @@ def initializeFolder():
 	if not os.path.exists(home+"/.deepface/weights"):
 		os.mkdir(home+"/.deepface/weights")
 		print("Directory ",home,"/.deepface/weights created")
-	
-def findThreshold(model_name, distance_metric):
-	
-	base_threshold = {'cosine': 0.40, 'euclidean': 0.55, 'euclidean_l2': 0.75}
-	
-	thresholds = {
-		'VGG-Face': {'cosine': 0.40, 'euclidean': 0.55, 'euclidean_l2': 0.75},
-		'OpenFace': {'cosine': 0.10, 'euclidean': 0.55, 'euclidean_l2': 0.55},
-		'Facenet':  {'cosine': 0.40, 'euclidean': 10, 'euclidean_l2': 0.80},
-		'DeepFace': {'cosine': 0.23, 'euclidean': 64, 'euclidean_l2': 0.64},
-		'DeepID': 	{'cosine': 0.015, 'euclidean': 45, 'euclidean_l2': 0.17},
-		'Dlib': 	{'cosine': 0.07, 'euclidean': 0.6, 'euclidean_l2': 0.6}
-		}
 
-	threshold = thresholds.get(model_name, base_threshold).get(distance_metric, 0.4)
-	
-	return threshold
+def loadBase64Img(uri):
+   encoded_data = uri.split(',')[1]
+   nparr = np.fromstring(base64.b64decode(encoded_data), np.uint8)
+   img = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
+   return img
 
 def get_opencv_path():
 	opencv_home = cv2.__file__
@@ -418,6 +401,8 @@ def align_face(img, detector_backend = 'opencv'):
 	
 def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_detection = True, detector_backend = 'opencv'):
 	
+	#img_path = copy.copy(img)
+	
 	#img might be path, base64 or numpy array. Convert it to numpy whatever it is.
 	img = load_image(img)
 	base_img = img.copy()
@@ -447,3 +432,18 @@ def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_dete
 	img_pixels /= 255 #normalize input in [0, 1]
 	
 	return img_pixels
+
+def find_input_shape(model):
+	
+	#face recognition models have different size of inputs
+	#my environment returns (None, 224, 224, 3) but some people mentioned that they got [(None, 224, 224, 3)]. I think this is because of version issue.
+	
+	input_shape = model.layers[0].input_shape
+	
+	if type(input_shape) == list:
+		input_shape = input_shape[0][1:3]
+	else:
+		input_shape = input_shape[1:3]
+	
+	return input_shape
+	
